/*
 * Copyright (c) 2000 Blue Mug, Inc.  All Rights Reserved.
 */

#include <netarm/ioregs.h>
#include <target/io.h>
#include "memmap.h"

static const char hermit_blocking[]   =  "4x8K/l";
static const char reserved_blocking[] =  "4x8K";
static const char user_blocking[]     = "55x64K";
static const char fpga_blocking[]     =  "8x64K/l";

/*
 * The only vaguely tricky things about this memory map are:
 *
 * (1) It includes remapped memory addresses for the inverted mapping
 *     used by the CSC in boot mode, if we're compiling for that
 *     target.
 *
 * (2) Depicts flash block sizes as they are seen from outside the
 *     boot loader.  The flash parts are 16 bits wide (each spans 16
 *     bits of the data bus), so the blocks as seen by a flash
 *     programmer are twice data sheet size (of each 32-bit write, 16
 *     bits goes to each flash chip).
 */
static int memmap_cmdfunc(int argc, char *argv[])
{
	hprintf("%p:%p FLA hermit bf:8K bl:%s\n"         \
                "%p:%p FLA reserved bf:8K bl:%s\n"       \
                "%p:%p FLA user bf:8K bl:%s\n"           \
                "%p:%p FLA fpga bf:8K bl:%s\n"           \
		"%p:%p RAM dram\n",
                HERMIT_START, HERMIT_START + HERMIT_SIZE - 1, hermit_blocking,
		RESERVED_START, RESERVED_START + RESERVED_SIZE - 1, reserved_blocking,
                USER_START, USER_START + USER_SIZE - 1, user_blocking,
                FPGA_START, FPGA_START + FPGA_SIZE - 1, fpga_blocking,
		DRAM_START, DRAM_START + DRAM_SIZE - 1);
	return 0;
}

const command_t memmap_command =
	{ "memmap", 0, "output memory map", &memmap_cmdfunc };

